dat.anker2025: Cardiology Example Data with Subgroup and Interaction Effects

dat.anker2025R Documentation

Cardiology Example Data with Subgroup and Interaction Effects

Description

Treatment effects, overall and in male/female patient subgroups, as well as treatment-by-subgroup interaction effects in six randomized, placebo-controlled trials.

Usage

dat.anker2025

Format

The data frame contains the following columns:

study character study identifier
year integer study year
intv.n integer number of patients in the intervention group
placebo.n integer number of patients in the placebo group
iv.iron factor the intravenous (IV) iron formulation investigated
size factor study size (“small” or “large”, based on total number of patients)
followup numeric followup duration (months)
baseline.age numeric mean age at baseline (years)
baseline.lvef numeric mean left ventricular ejection fraction (LVEF) at baseline (%)
baseline.hgb numeric mean haemoglobin at baseline (g/dl)
baseline.ft numeric mean ferritin at baseline (\mug/l)
baseline.tsat numeric mean transferritin saturation (TSAT) at baseline (%)
total.n integer total number of patients
total.logrr numeric overall effect (log-RR)
total.se numeric standard error of overall effect
female.n integer number of female patients
female.logrr numeric effect (log-RR) in females
female.se numeric standard error of effect in females
male.n integer number of male patients
male.logrr numeric effect (log-RR) in males
male.se numeric standard error of effect in males
sex.logrrr numeric treatment-by-subgroup interaction (log-RRR)
sex.se numeric standard error of treatment-by-subgroup interaction

Details

Anker et al. (2025) analyzed the effects of intravenous (IV) iron therapy observed in six randomized, placebo-controlled trials. The primary endpoint was a composite of (recurrent) heart failure (HF) hospitalizations and cardiovascular (CV) death, and treatment effects were quantified in terms of risk ratios (RRs). Individual participant data were available for five trials, and analyses were harmonized to match the analysis of the sixth trial (the Ironman study). Meta-analyses were then performed based on logarithmic RRs (log-RRs).

Besides investigation of the overall effect, it was of interest to what extent male and female patients benefited, and whether effects differed between both patient subgroups. The data set includes effect estimates within each study's male and female subgroups (in terms of log-RRs), as well as estimates of the difference between the subgroups (in terms of logarithmic ratios of RRs (log-RRRs). Technically, the RRRs then constitute treatment-by-subgroup interaction effects.

Concepts

medicine, cardiology, incidence rates

Author(s)

Christian Roever, christian.roever@med.uni-goettingen.de

Anker, S. D., Karakas, M., Mentz, R. J., Ponikowski, P., Butler, J., Khan, M. S., Talha, K. M., Kalra, P. R., Hernandez, A. F., Mulder, H., Rockhold, F. W., Placzek, M., Röver, C., Cleland, J. G. F., & Friede, T. (2025). Systematic review and meta-analysis of intravenous iron therapy for patients with heart failure and iron deficiency. Nature Medicine, 31(8), 2640-2646. ⁠https://doi.org/10.1038/s41591-025-03671-1⁠

Examples

# show data
dat.anker2025
## Not run: 
library(bayesmeta)

# specify heterogeneity (tau) prior density (half-normal(0.5))
HN05 <- function(t){dhalfnormal(t, scale=0.5)}

#######################################
#  reproduce primary analysis (Fig.2)
es.primary <- escalc(measure="IRR", yi=total.logrr, sei=total.se,
                     ni=total.n, slab=study, data=dat.anker2025)
bma01 <- bayesmeta(es.primary, tau.prior=HN05)
forestplot(bma01, expo=TRUE, xlog=TRUE,
           xlab="rate ratio (RR)", title="HF hospitalizations / CV mortality")

######################################
#  reproduce sex interaction analysis
#  (Tab.2, Supplementary Fig.4)
es.sex <- escalc(measure="GEN", yi=sex.logrrr, sei=sex.se,
                 ni=total.n, slab=study, data=dat.anker2025)
bma02 <- bayesmeta(es.sex, tau.prior=HN05)
forestplot(bma02, expo=TRUE, xlog=TRUE,
           xlab="ratio of RRs (RRR)", title="sex interaction (females/males)")

###########################################
#  reproduce male/female subgroup analyses
#  (Tab.2, Supplementary Fig.12)
es.female <- escalc(measure="IRR", yi=female.logrr, sei=female.se,
                    ni=female.n, slab=study, data=dat.anker2025)
es.male   <- escalc(measure="IRR", yi=male.logrr, sei=male.se,
                    ni=male.n, slab=study, data=dat.anker2025)
bma03a <- bayesmeta(es.female, tau.prior=HN05)
bma03b <- bayesmeta(es.male, tau.prior=HN05)
forestplot(bma03a, expo=TRUE, xlog=TRUE,
           xlab="rate ratio (RR)", title="female subgroup")
forestplot(bma03b, expo=TRUE, xlog=TRUE,
           xlab="rate ratio (RR)", title="male subgroup")

## End(Not run)

metadat documentation built on April 29, 2026, 5:10 p.m.