dat.bauer2002: Studies on OM-89 (Uro-Vaxom) in Urinary Tract Infections

dat.bauer2002R Documentation

Studies on OM-89 (Uro-Vaxom) in Urinary Tract Infections

Description

Estimated Wilcoxon-Mann-Whitney (WMW) effect sizes from five studies on OM-89 (Uro-Vaxom) in patients with recurrent urinary tract infections.

Usage

dat.bauer2002

Format

The data frame contains the following columns:

study character study identifier
year numeric publication year
threshold numeric threshold (for bacteriuria / UTI definition)
n.treat numeric number of patients in treatment group
n.control numeric number of patients in control group
n.total numeric total number of patients
wmwstat numeric Wilcoxon-Mann-Whitney statistic
lower numeric lower CI bound for the WMW-statistic
upper numeric upper CI bound for the WMW-statistic
stderr numeric standard error for the WMW-statistic

Details

Bauer et al. (2002) analyzed data from five randomized, placebo-controlled studies investigating the use of OM-89 (Uro-Vaxom) in recurrent urinary tract infections (UTI). Treatment effects were quantified in terms of the Wilcoxon-Mann-Whitney statistic computed based on the numbers of recurrences experienced by included patients from each study.

The WMW-statistic gives an estimate of the probability that a randomly selected patient from the treatment group is superior to a randomly selected control patient, also denoted as the common language effect size (CLES). “Superiority” in this case relates to fewer UTI recurrences experienced. A WMW-statistic >0.5 then suggests a beneficial treatment effect.

Concepts

medicine, common-language effect sizes, proportions

Author(s)

Christian Röver, christian.roever@med.uni-goettingen.de

Bauer, H. W., Rahlfs, V. W., Lauener, P. A., & Bleßmann, G. S. S. (2002). Prevention of recurrent urinary tract infections with immuno-active E. coli fractions: A meta-analysis of five placebo-controlled double-blind studies. International Journal of Antimicrobial Agents, 19(6), 451–456. ⁠https://doi.org/10.1016/s0924-8579(02)00106-1⁠

See Also

dat.huber2000

Examples

dat.bauer2002

## Not run: 
library(metafor)
library(bayesmeta)

# analyze based on plain probabilities as effect sizes
wmw.prob <- escalc(measure="CLES",
                   yi = wmwstat, sei = stderr,
                   ni = n.total, slab = study,
                   data = dat.bauer2002)

# perform a random-effects meta-analysis
ma01 <- rma.uni(wmw.prob, method="PM", test="adhoc")

# show forest plot
forest(ma01, addpred=TRUE, predstyle="bar",
       refline=0.5, main="dat.bauer2002 (probabilities)")


# analyze based on log-odds (logits) as effect sizes
wmw.logit <- escalc(measure="PLO",
                    yi   = log(wmwstat / (1-wmwstat)),
                    sei  = stderr / (wmwstat*(1-wmwstat)),
                    ni   = n.total, slab = study,
                    data = dat.bauer2002)

# perform a random-effects meta-analysis
ma02 <- rma.uni(wmw.logit, method="PM", test="adhoc")

# show forest plot (back-transformed to probabilities)
forest(ma02, addpred=TRUE, predstyle="bar",
       transf=transf.ilogit,
       header=c("study", "CLES [95 percent CI]"),
       xlab="common language effect size",
       refline=0.5, main="dat.bauer2002 (log-odds)")

# show forest plot (in terms of log-odds)
forest(ma02, addpred=TRUE, predstyle="bar",
       header=c("study", "logit(CLES) [95 percent CI]"),
       xlab="logit(common language effect size)",
       refline=0.0, main="dat.bauer2002 (log-odds)")

# perform Bayesian meta-analsis
# (using a half-normal prior for the (logit-WMW) effect heterogeneity
#  and a Normal(0.0, 1.814) prior for the overall mean logit;
#  the overall mean prior (with variance (pi/sqrt(3))^2)
#  roughly corresponds to a uniform prior in probability)
ma03 <- bayesmeta(wmw.logit,
                  tau.prior = function(t){dhalfnormal(t,scale=0.5)},
                  mu.prior = c(0.0, 1.814))
forestplot(ma03, title = "dat.bauer2002 (log-odds)",
           xlab = "logit(CLES)",
           txt_gp = fpTxtGp(ticks = gpar(cex=1), xlab = gpar(cex=1)))

## End(Not run)

metadat documentation built on April 29, 2026, 5:10 p.m.