Learn R Programming

metadat (version 1.4-0)

dat.crisafulli2020: Duchenne Muscular Dystrophy (DMD) Prevalence Data

Description

26 studies reporting estimates of the birth prevalence of Duchenne muscular dystrophy.

Usage

dat.crisafulli2020

Arguments

Format

The data frame contains the following columns:

studycharacterstudy label (first author, year)
pubyearintegerpublication year
countryfactororigin of investigated population
from, tointegertime span of investigation (years)
casesintegernumber of DMD cases
totalintegercorresponding total population

Concepts

medicine, epidemiology, proportions, dose-response models

Details

Duchenne muscular dystrophy (DMD) is a rare disease that is caused by a genetic mutation and is characterized by impairment through muscle weakness and a reduced life expectancy.

Crisafulli et al. (2020) reported on a systematic review of data on the epidemiology of DMD, including estimates of the birth prevalence (which is of the order of a few per ten thousand). One of the originally reported studies (Koenig, 2019) is omitted here, as it constitutes an obvious outlier, and the reliability of the reported data is doubtful; Crisafulli et al. (2020) pointed out that “Concerning birth prevalence, Koenig et al. were found to be outliers. This study had problems with data collection in the last study year, as due to privacy issues, DMD cases were under-reported.

Examples

Run this code
# show (some) data
head(dat.crisafulli2020)

if (FALSE) {
# compute logarithmic proportions and associated standard errors
library(metafor)
logp <- escalc(measure="PLN",
               xi=cases, ni=total, slab=study,
               data=dat.crisafulli2020)

# perform meta-analysis
rma01 <- rma.uni(logp)

# show results
rma01

# illustrate in a forest plot
forest(rma01, xlim=c(-12,-5))
}

Run the code above in your browser using DataLab