Learn R Programming

metadat (version 1.4-0)

dat.curtin2002: Studies on Potassium Supplementation to Reduce Diastolic Blood Pressure

Description

Results from 21 cross-over studies evaluating the effect of potassium supplementation to reduce diastolic blood pressure.

Usage

dat.curtin2002

Arguments

Format

The data frame contains the following columns:

authorcharacterfirst author
yearcharacteryear of publication
Nintegertotal sample size
meannumericmean difference in diastolic blood pressure
SEnumericstandard error
corrnumericwithin-patient correlation

Concepts

raw mean differences

Details

Results from 21 cross-over studies evaluating the effect of potassium supplementation to reduce diastolic blood pressure (Curtin et al., 2002, Table II).

This data set is used as an example in Schwarzer et al. (2015), Chapter 2.

References

Schwarzer, G., Carpenter, J. R., & Rücker, G. (2015). Meta-analysis with R. Cham, Switzerland: Springer.

Examples

Run this code
### Show first five studies
head(dat.curtin2002, 5)

if (FALSE) {
### Load meta package
suppressPackageStartupMessages(library("meta"))

### Use DerSimonian-Laird estimator (which was the default in meta in the year 2015).
### Furthermore, print meta-analysis results with two digits.
oldset <- settings.meta(method.tau = "DL", digits = 2)

### Conduct meta-analysis
mg2 <- metagen(mean, SE, studlab = paste(author, year),
               data = dat.curtin2002, sm = "MD")
mg2

### Use previous settings
settings.meta(oldset)
}

Run the code above in your browser using DataLab