dat.greb2008: Trials on High-Dose Chemotherapy with Autologous Stem Cell...

dat.greb2008R Documentation

Trials on High-Dose Chemotherapy with Autologous Stem Cell Transplantation in Aggressive Non-Hodgkin Lymphoma

Description

Results on complete response from 14 trials evaluating high-dose chemotherapy with autologous stem cell transplantation in patients with aggressive non-Hodgkin lymphoma.

Usage

dat.greb2008

Format

The data frame contains the following columns:

study character study label
Ee integer complete responses (high-dose chemotherapy)
Ne integer number of patients (high-dose chemotherapy)
Ec integer complete responses (standard chemotherapy)
Nc integer number of patients (standard chemotherapy)

Details

Greb et al. (2008) conducted a Cochrane Review to assess the effects of high-dose chemotherapy with autologous stem cell transplantation as part of the first-line treatment of adult patients with aggressive non-Hodgkin lymphoma. The primary outcome was survival time; the binary outcome ‘complete response’ was one of several secondary outcomes. For binary outcomes, the Cochrane review used the risk ratio and the common effect model.

This data set is used as an example in Schwarzer et al. (2015).

Concepts

medicine, oncology, risk ratios

Author(s)

Guido Schwarzer, guido.schwarzer@uniklinik-freiburg.de, https://github.com/guido-s/

Greb, A., Bohlius, J., Schiefer, D., Schwarzer, G., Schulz, H., & Engert, A. (2008). High-dose chemotherapy with autologous stem cell transplantation in the first line treatment of aggressive Non-Hodgkin Lymphoma (NHL) in adults. Cochrane Database of Systematic Reviews, 1, CD004024. ⁠https://doi.org/10.1002/14651858.cd004024.pub2⁠

References

Schwarzer, G., Carpenter, J. R., & Rücker, G. (2015). Meta-analysis with R. Cham, Switzerland: Springer.

Examples

### Show first five studies
head(dat.greb2008, 5)

## Not run: 
### Load meta package
suppressPackageStartupMessages(library(meta))

### Use RevMan 5 settings
oldset <- settings.meta("RevMan5")

### Conduct common effect meta-analysis with risk ratio as effect measure
mb1 <- metabin(Ee, Ne, Ec, Nc,
  data = dat.greb2008, studlab = study,
  label.e = "High dose", label.c = "Standard",
  label.left = "Favours standard chemotherapy",
  label.right = "Favours high dose chemotherapy",
  col.label.left = "red", col.label.right = "green")
mb1

### Create forest plot
forest(mb1)

### Use previous settings
settings.meta(oldset)

## End(Not run)

metadat documentation built on April 29, 2026, 5:10 p.m.