dat.greenland1992: Case-Control Studies on the Impact of Alcohol Consumption on...

dat.greenland1992R Documentation

Case-Control Studies on the Impact of Alcohol Consumption on Breast Cancer Risk

Description

Results from 16 case-control studies evaluating the impact of alcohol consumption on breast cancer risk.

Usage

dat.greenland1992

Format

The data frame contains the following columns:

author character first author
year integer publication year
b numeric adjusted log risk ratio
SE numeric standard error

Details

Greenland and Longecker (1992) describe a method to combine trend estimates from summarized dose-response data. A meta-analysis of 16 case-control studies evaluating the impact of alcohol consumption on breast cancer risk was used as an illustrative example. The estimates are the increase in the log relative risk of breast cancer associated with an average daily alcohol consumption of 1g.

Data are provided in Greenland and Longecker (1992), Table 3.

Concepts

epidemiology, risk ratios

Author(s)

Guido Schwarzer, guido.schwarzer@uniklinik-freiburg.de, https://github.com/guido-s/

Greenland, S., & Longnecker, M. P. (1992). Methods for trend estimation from summarized dose-response data, with applications to meta-analysis. American Journal of Epidemiology, 135(11), 1301–1309. ⁠https://doi.org/10.1093/oxfordjournals.aje.a116237⁠

Examples

### Show first 6 rows of the dataset
head(dat.greenland1992)

## Not run: 
### Load meta package
suppressPackageStartupMessages(library(meta))

### Inverse variance method
mg <- metagen(b, SE, data = dat.greenland1992,
  studlab = paste(author, year), sm = "RR",
  random = FALSE, overall.hetstat = FALSE,
  backtransf = FALSE)

### Overall result
print(mg, digits = 5)

### Standard error for common effect estimate
round(mg$seTE.common, 5)

## End(Not run)

metadat documentation built on April 29, 2026, 5:10 p.m.