Learn R Programming

metadat (version 1.4-0)

dat.anand1999: Studies on the Effectiveness of Oral Anticoagulants in Patients with Coronary Artery Disease

Description

Results from 34 trials examining the effectiveness of oral anticoagulants in patients with coronary artery disease.

Usage

dat.anand1999

Arguments

Format

The data frame contains the following columns:

studycharacterauthor(s) or trial name
yearnumericpublication year
intensitycharacterintensity of anticoagulation (low, medium, or high)
asp.tnumericconcomitant use of aspirin in the treatment group (0 = no, 1 = yes)
asp.cnumericconcomitant use of aspirin in the control group (0 = no, 1 = yes)
ainumericnumber of deaths in the treatment group
n1inumericnumber of patients in the treatment group
cinumericnumber of deaths in the control group
n2inumericnumber of patients in the control group

Concepts

medicine, cardiology, odds ratios, Mantel-Haenszel method

Details

The dataset includes the results from 34 randomized clinical trials that examined the effectiveness of oral anticoagulants in patients with coronary artery disease. The results given here are focused on the total mortality in the treatment versus control groups.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.anand1999
dat

if (FALSE) {
### load metafor package
library(metafor)

### High-Intensity OA vs Control
rma.mh(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat,
       subset=(intensity=="high" & asp.t==0 & asp.c==0), digits=2)

### High- or Moderate-Intensity OA vs Aspirin
rma.mh(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat,
       subset=(intensity %in% c("high","moderate") & asp.t==0 & asp.c==1), digits=2)

### Moderate-Intensity OA vs Control
rma.mh(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat,
       subset=(intensity=="moderate" & asp.t==0 & asp.c==0), digits=2)

### High- or Moderate-Intensity OA and Aspirin vs Aspirin
rma.mh(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat,
       subset=(intensity %in% c("high","moderate") & asp.t==1 & asp.c==1), digits=2)

### Low-Intensity OA and Aspirin vs Aspirin
rma.mh(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat,
       subset=(intensity=="low" & asp.t==1 & asp.c==1), digits=2)
}

Run the code above in your browser using DataLab