Learn R Programming

metadat (version 1.4-0)

dat.axfors2021: Mortality Outcomes with Hydroxychloroquine and Chloroquine in COVID-19 from an International Collaborative Meta-Analysis of Randomized Trials

Description

Results from 33 trials examining the effectiveness of hydroxychloroquine or chloroquine in patients with COVID-19.

Usage

dat.axfors2021

Arguments

Format

The data frame contains the following columns:

idcharacterregistry number
acronymcharactershortened registry number
patient_settingcharacterpatient setting
blinding_exactcharacterstudy blinding
high_dosecharacterhigh or low dose of medication
Publishedcharacterpublication status
hcq_cqcharactermedication type (hcq = hydroxychloroquine or cq = chloroquine)
hcq_arm_eventnumericnumber of deaths in the treatment group
hcq_arm_totalnumericnumber of patients in the treatment group
control_arm_eventnumericnumber of deaths in the control group
control_arm_totalnumericnumber of patients in the control group
Controlcharactercontrol group type (Standard of Care or Placebo)

Concepts

medicine, covid-19, odds ratios

Details

The dataset includes the results from 33 published and unpublished randomized clinical trials that examined the effectiveness of hydroxychloroquine or chloroquine in patients with COVID-19. The results given here are focused on the total mortality in the treatment versus control groups.

References

Axfors, C., Schmitt, A. M., Janiaud, P., van’t Hooft, J., Abd-Elsalam, S., Abdo, E. F., Abella, B. S., Akram, J., Amaravadi, R. K., Angus, D. C., Arabi, Y. M., Azhar, S., Baden, L. R., Baker, A. W., Belkhir, L., Benfield, T., Berrevoets, M. A. H., Chen, C.-P., Chen, T.-C., … Hemkens, L. G. (2021). Mortality outcomes with hydroxychloroquine and chloroquine in COVID-19 from an international collaborative meta-analysis of randomized trials. Nature Communications, 12(1), 2349. https://doi.org/10.1038/s41467-021-22446-z

Examples

Run this code
# copy data into 'dat' and examine data
dat <- dat.axfors2021
dat

if (FALSE) {
# load metafor package
library(metafor)

# calculate log odds ratios and corresponding sampling variances
dat <- escalc(measure="OR", ai=hcq_arm_event, n1i=hcq_arm_total,
                            ci=control_arm_event, n2i=control_arm_total, data=dat)

# meta-analysis Hydroxychloroquine
res_hcq <- rma(yi, vi, subset=(hcq_cq=="hcq"), slab = id, data=dat)
print(res_hcq, digits=2)

# meta-analysis Chloroquine
res_cq <- rma(yi, vi, subset=(hcq_cq=="cq"), slab = id, data=dat)
print(res_cq, digits=2)
}

Run the code above in your browser using DataLab