Learn R Programming

metadat (version 1.4-0)

dat.bangertdrowns2004: Studies on the Effectiveness of Writing-to-Learn Interventions

Description

Results from 48 studies on the effectiveness of school-based writing-to-learn interventions on academic achievement.

Usage

dat.bangertdrowns2004

Arguments

Format

The data frame contains the following columns:

idnumericstudy number
authorcharacterstudy author(s)
yearnumericpublication year
gradenumericgrade level (1 = elementary; 2 = middle; 3 = high-school; 4 = college)
lengthnumerictreatment length (in weeks)
minutesnumericminutes per assignment
wicnumericwriting tasks were completed in class (0 = no; 1 = yes)
feedbacknumericfeedback on writing was provided (0 = no; 1 = yes)
infonumericwriting contained informational components (0 = no; 1 = yes)
persnumericwriting contained personal components (0 = no; 1 = yes)
imagnumericwriting contained imaginative components (0 = no; 1 = yes)
metanumericprompts for metacognitive reflection (0 = no; 1 = yes)
subjectcharactersubject matter
ninumerictotal sample size of the study
yinumericstandardized mean difference
vinumericcorresponding sampling variance

Concepts

education, standardized mean differences, meta-regression

Details

In each of the studies included in this meta-analysis, an experimental group (i.e., a group of students that received instruction with increased emphasis on writing tasks) was compared against a control group (i.e., a group of students that received conventional instruction) with respect to some content-related measure of academic achievement (e.g., final grade, an exam/quiz/test score). The outcome measure for this meta-analysis was the standardized mean difference (with positive values indicating a higher mean level of academic achievement in the intervention group).

The standardized mean differences given here are bias-corrected and therefore differ slightly from the values reported in the article. Also, since only the total sample size is given in the article, the sampling variances were computed under the assumption that n_i1 = n_i2 = n_i / 2n_i1 = n_i2 = n_i / 2.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.bangertdrowns2004
dat[1:10,-13]

if (FALSE) {
### load metafor package
library(metafor)

### fit random-effects model
res <- rma(yi, vi, data=dat)
res

### some examples of mixed-effects meta-regression models
res <- rma(yi, vi, mods = ~ factor(grade), data=dat)
res
res <- rma(yi, vi, mods = ~ length, data=dat)
res
res <- rma(yi, vi, mods = ~ info + pers + imag + meta, data=dat)
res
}

Run the code above in your browser using DataLab