Learn R Programming

metadat (version 1.4-0)

dat.bassler2004: Studies on Ketotifen Alone or as Additional Medication for Long-Term Control of Asthma and Wheeze in Children

Description

Results from 10 trials reporting the physicians' judgement on the overall efficacy of ketotifen for long-term control of asthma and wheeze in children.

Usage

dat.bassler2004

Arguments

Format

The data frame contains the following columns:

studycharacterstudy label
Eeintegernumber of children with treament success (ketotifen group)
Neintegernumber of children (ketotifen group)
Ecintegernumber of children with treament success (control group)
Ncintegernumber of children (control group)
blindcharacterblinding of clinicians

Concepts

risk ratios, medicine, subgroup analysis

Details

Results from 10 trials reporting the physicians' judgement on the overall efficacy of Ketotifen for long-term control of asthma and wheeze in children. A prespecified subgroup analysis was conducted to evaluate whether the treatment effect is different in trials with adequate blinding compared to trials with inadequate / unclear blinding.

This data set is used as an example in Schwarzer et al. (2015).

References

Schwarzer, G., Carpenter, J. R., & Rücker, G. (2015). Meta-analysis with R. Cham, Switzerland: Springer.

Examples

Run this code
### Show full data set
dat.bassler2004

if (FALSE) {
### Load meta package
suppressPackageStartupMessages(library("meta"))

### Use DerSimonian-Laird estimator (which was the default in meta in the year 2015).
### Furthermore, print meta-analysis results with two digits.
oldset <- settings.meta(method.tau = "DL", digits = 2)

### Calculate experimental and control event rates
with(dat.bassler2004, summary(Ee / Ne))
with(dat.bassler2004, summary(Ec / Nc))

### Conduct meta-analysis using the inverse variance method
mb3 <- metabin(Ee, Ne, Ec, Nc, method = "I",
               data = dat.bassler2004, studlab = study)
mb3

### Conduct subgroup analysis comparing trials with adequate blinding
### to trials with inadequate or unclear blinding
mb3s <- update(mb3, subgroup = blind, print.subgroup.name = FALSE)
mb3s

### Conduct subgroup analysis assuming common between-study variance in subgroups
mb3s.c <- update(mb3s, tau.common = TRUE)
mb3s.c

### Use previous settings
settings.meta(oldset)
}

Run the code above in your browser using DataLab