Learn R Programming

metadat (version 1.4-0)

dat.bonett2010: Studies on the Reliability of the CES-D Scale

Description

Results from 9 studies on the reliability of the Center for Epidemiologic Studies Depression (CES-D) Scale administered to children providing care to an elderly parent.

Usage

dat.bonett2010

Arguments

Format

The data frame contains the following columns:

studynumericstudy number
sourcecharactersource of data
ninumericsample size
minumericnumber of items in the scale
ainumericobserved value of Cronbach's alpha
caregiverscharactergender of the children in the sample

Concepts

psychology, Cronbach's alpha, reliability generalization, meta-regression

Details

The Center for Epidemiologic Studies Depression (CES-D) Scale is a 20-item questionnaire assessing various symptoms of depression, with each item scored on a 4-point scale. The scale has been used in several studies to examine depressive symptoms in children providing care to an elderly parent. The dataset includes information on the reliability of the scale as measured with Cronbach's alpha in 9 such studies. Also, the gender composition of the children in each sample is indicated.

References

Bonett, D. G. (2002). Sample size requirements for testing and estimating coefficient alpha. Journal of Educational and Behavioral Statistics, 27(4), 335--340. https://doi.org/10.3102/10769986027004335

Hakstian, A. R., & Whalen, T. E. (1976). A k-sample significance test for independent alpha coefficients. Psychometrika, 41(2), 219--231. https://doi.org/10.1007/BF02291840

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.bonett2010
dat

if (FALSE) {
### load metafor package
library(metafor)

### meta-analysis using the raw alpha values
res <- rma(measure="ARAW", ai=ai, mi=mi, ni=ni, data=dat)
res

### meta-analysis using transformed alpha values (using the
### transformation suggested by Hakstian & Whalen, 1976)
res <- rma(measure="AHW", ai=ai, mi=mi, ni=ni, data=dat)
res
predict(res, transf=transf.iahw)

### meta-analysis using transformed alpha values (using the
### transformation suggested by Bonett, 2002)
res <- rma(measure="ABT", ai=ai, mi=mi, ni=ni, data=dat)
res
predict(res, transf=transf.iabt)

### forest plot
forest(res, slab=source, xlim=c(0,4.5),
       atransf=transf.iabt, refline=coef(res))

### examine whether female/mixed samples yield different alphas (with raw alphas)
res <- rma(measure="ARAW", ai=ai, mi=mi, ni=ni, mods = ~ caregivers, data=dat)
res
predict(res, newmods=c(0,1), digits=2)
}

Run the code above in your browser using DataLab