Learn R Programming

metadat (version 1.4-0)

dat.cannon2006: Studies on the Effectiveness of Intensive Versus Moderate Statin Therapy for Preventing Coronary Death or Myocardial Infarction

Description

Results from 4 trials examining the effectiveness of intensive (high dose) versus moderate (standard dose) statin therapy for preventing coronary death or myocardial infarction.

Usage

dat.cannon2006

Arguments

Format

The data frame contains the following columns:

trialcharactertrial name
popcharacterstudy population (post-ACS: post acute coronary syndrome; stable CAD: stable coronary artery disease)
ntnumericnumber of patients in the high dose group
ncnumericnumber of patients in the standard dose group
ep1tnumericnumber of events in the high dose group for end point 1: coronary death or non-fatal myocardial infarction
ep1cnumericnumber of events in the standard dose group for end point 1: coronary death or non-fatal myocardial infarction
ep2tnumericnumber of events in the high dose group for end point 2: coronary death or any cardiovascular event (MI, stroke, hospitalization for unstable angina, or revascularization)
ep2cnumericnumber of events in the standard dose group for end point 2: coronary death or any cardiovascular event (MI, stroke, hospitalization for unstable angina, or revascularization)
ep3tnumericnumber of events in the high dose group for end point 3: cardiovascular death
ep3cnumericnumber of events in the standard dose group for end point 3: cardiovascular death
ep4tnumericnumber of events in the high dose group for end point 4: non-cardiovascular death
ep4cnumericnumber of events in the standard dose group for end point 4: non-cardiovascular death
ep5tnumericnumber of events in the high dose group for end point 5: deaths (all-cause mortality)
ep5cnumericnumber of events in the standard dose group for end point 5: deaths (all-cause mortality)
ep6tnumericnumber of events in the high dose group for end point 6: stroke
ep6cnumericnumber of events in the standard dose group for end point 6: stroke

Concepts

medicine, cardiology, odds ratios, Mantel-Haenszel method

Details

The data were obtained from Figures 2, 3, 4, and 5 in Cannon et al. (2006). The authors used the Mantel-Haenszel method for combining the results from the 4 trials. This approach is implemented in the rma.mh function.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.cannon2006
dat

if (FALSE) {
### load metafor package
library(metafor)

### meta-analysis of log odds ratios using the MH method for endpoint 1
res <- rma.mh(measure="OR", ai=ep1t, n1i=nt, ci=ep1c, n2i=nc, data=dat, slab=trial)
print(res, digits=2)

### forest plot
forest(res, xlim=c(-.8,0.8), atransf=exp, at=log(c(2/3, 1, 3/2)),
       cex=1.2, xlab="Odds Ratio")
mtext("(high dose better)", side=1, line=par("mgp")[1]-0.5, at=log(2/3), cex=1.2, font=3)
mtext("(standard dose better)", side=1, line=par("mgp")[1]-0.5, at=log(3/2), cex=1.2, font=3)
}

Run the code above in your browser using DataLab