Results from 10 studies on the relationship between the Competitive State Anxiety Inventory-2 (CSAI-2) and sport performance.

dat.craft2003

Format

The data frame contains the following columns:

studynumericstudy number
ninumericsample size
sportcharactertype of sport (T = team sport, I = individual sport)
rinumericcorrelation coefficient
var1charactervariable 1 of the correlation coefficient (see ‘Details’)
var2charactervariable 2 of the correlation coefficient (see ‘Details’)

Details

The 10 studies included in this dataset are a subset of the studies included in the meta-analysis by Craft et al. (2003) on the relationship between the Competitive State Anxiety Inventory-2 (CSAI-2) and sport performance.

The CSAI-2 has three subscales: cognitive anxiety (acog), somatic anxiety (asom), and self-confidence (conf). The studies included in this dataset administered the CSAI-2 prior to some sport competition and then measured sport performance based on the competition. Most studies provided all 6 correlations (3 for the correlations among the 3 subscales and 3 for the correlations between the subscales and sport performance), but 2 studies (with study numbers 6 and 17) only provided a subset.

Becker, B. J., & Aloe, A. M. (2019). Model-based meta-analysis and related approaches. In H. Cooper, L. V. Hedges, & J. C. Valentine (Eds.), The handbook of research synthesis and meta-analysis (3nd ed., pp. 339–363). New York: Russell Sage Foundation.

References

Craft, L. L., Magyar, T. M., Becker, B. J., & Feltz, D. L. (2003). The relationship between the Competitive State Anxiety Inventory-2 and sport performance: A meta-analysis. Journal of Sport and Exercise Psychology, 25(1), 44–65. https://doi.org/10.1123/jsep.25.1.44

Concepts

psychology, correlation coefficients, multivariate models

Examples

### copy data into 'dat' and examine data
dat <- dat.craft2003
head(dat, 18)
#>    study  ni sport    ri var1 var2
#> 1      1 142     I -0.55 acog perf
#> 2      1 142     I -0.48 asom perf
#> 3      1 142     I  0.66 conf perf
#> 4      1 142     I  0.47 acog asom
#> 5      1 142     I -0.38 acog conf
#> 6      1 142     I -0.46 asom conf
#> 7      3  37     I  0.53 acog perf
#> 8      3  37     I -0.12 asom perf
#> 9      3  37     I  0.03 conf perf
#> 10     3  37     I  0.52 acog asom
#> 11     3  37     I -0.48 acog conf
#> 12     3  37     I -0.40 asom conf
#> 13     6  16     T  0.44 acog perf
#> 14     6  16     T  0.46 asom perf
#> 15     6  16     T    NA conf perf
#> 16     6  16     T  0.67 acog asom
#> 17     6  16     T    NA acog conf
#> 18     6  16     T    NA asom conf

### load metafor package
library(metafor)

### construct dataset and var-cov matrix of the correlations
tmp <- rcalc(ri ~ var1 + var2 | study, ni=ni, data=dat)
V <- tmp$V
dat <- tmp$dat

### examine data for study 1
dat[dat$study == 1,]
#>   study var1 var2 var1.var2    yi  ni
#> 1     1 acog perf acog.perf -0.55 142
#> 2     1 asom perf asom.perf -0.48 142
#> 3     1 conf perf conf.perf  0.66 142
#> 4     1 acog asom acog.asom  0.47 142
#> 5     1 acog conf acog.conf -0.38 142
#> 6     1 asom conf asom.conf -0.46 142
V[dat$study == 1, dat$study == 1]
#> 
#>           acog.perf asom.perf conf.perf acog.asom acog.conf asom.conf 
#> acog.perf    0.0035    0.0013   -0.0006   -0.0014    0.0025    0.0009 
#> asom.perf    0.0013    0.0042   -0.0010   -0.0019    0.0013    0.0025 
#> conf.perf   -0.0006   -0.0010    0.0023    0.0006   -0.0015   -0.0011 
#> acog.asom   -0.0014   -0.0019    0.0006    0.0043   -0.0018   -0.0012 
#> acog.conf    0.0025    0.0013   -0.0015   -0.0018    0.0052    0.0019 
#> asom.conf    0.0009    0.0025   -0.0011   -0.0012    0.0019    0.0044 
#> 

### examine data for study 6
dat[dat$study == 6,]
#>    study var1 var2 var1.var2   yi ni
#> 13     6 acog perf acog.perf 0.44 16
#> 14     6 asom perf asom.perf 0.46 16
#> 15     6 conf perf conf.perf   NA 16
#> 16     6 acog asom acog.asom 0.67 16
#> 17     6 acog conf acog.conf   NA 16
#> 18     6 asom conf asom.conf   NA 16
V[dat$study == 6, dat$study == 6]
#> 
#>           acog.perf asom.perf conf.perf acog.asom acog.conf asom.conf 
#> acog.perf    0.0434    0.0256        NA    0.0095        NA        NA 
#> asom.perf    0.0256    0.0414        NA    0.0085        NA        NA 
#> conf.perf        NA        NA        NA        NA        NA        NA 
#> acog.asom    0.0095    0.0085        NA    0.0202        NA        NA 
#> acog.conf        NA        NA        NA        NA        NA        NA 
#> asom.conf        NA        NA        NA        NA        NA        NA 
#> 

### examine data for study 17
dat[dat$study == 17,]
#>    study var1 var2 var1.var2    yi ni
#> 25    17 acog perf acog.perf  0.10 45
#> 26    17 asom perf asom.perf  0.31 45
#> 27    17 conf perf conf.perf -0.17 45
#> 28    17 acog asom acog.asom    NA 45
#> 29    17 acog conf acog.conf    NA 45
#> 30    17 asom conf asom.conf    NA 45
V[dat$study == 17, dat$study == 17]
#> 
#>           acog.perf asom.perf conf.perf acog.asom acog.conf asom.conf 
#> acog.perf    0.0223        NA        NA        NA        NA        NA 
#> asom.perf        NA    0.0186        NA        NA        NA        NA 
#> conf.perf        NA        NA    0.0214        NA        NA        NA 
#> acog.asom        NA        NA        NA        NA        NA        NA 
#> acog.conf        NA        NA        NA        NA        NA        NA 
#> asom.conf        NA        NA        NA        NA        NA        NA 
#> 

### multivariate random-effects model
res <- rma.mv(yi, V, mods = ~ 0 + var1.var2, random = ~ var1.var2 | study, struct="UN", data=dat)
#> Warning: 9 rows with NAs omitted from model fitting.
res
#> 
#> Multivariate Meta-Analysis Model (k = 51; method: REML)
#> 
#> Variance Components:
#> 
#> outer factor: study     (nlvls = 9)
#> inner factor: var1.var2 (nlvls = 6)
#> 
#>             estim    sqrt  k.lvl  fixed      level 
#> tau^2.1    0.0047  0.0683      9     no  acog.asom 
#> tau^2.2    0.0125  0.1119      8     no  acog.conf 
#> tau^2.3    0.1611  0.4014      9     no  acog.perf 
#> tau^2.4    0.0111  0.1052      8     no  asom.conf 
#> tau^2.5    0.0604  0.2459      9     no  asom.perf 
#> tau^2.6    0.0468  0.2163      8     no  conf.perf 
#> 
#>            rho.acg.s  rho.acg.c  rho.acg.p  rho.asm.c  rho.asm.p  rho.cnf.    acg.s  acg.c  acg.p 
#> acog.asom          1                                                              -      8      9 
#> acog.conf    -0.6961          1                                                  no      -      8 
#> acog.perf     0.5491     0.0432          1                                       no     no      - 
#> asom.conf    -0.0891     0.4193     0.3532          1                            no     no     no 
#> asom.perf     0.4604    -0.0495     0.9497     0.2688          1                 no     no     no 
#> conf.perf    -0.9345     0.7023    -0.6178    -0.1311    -0.5969         1       no     no     no 
#>            asm.c  asm.p  cnf. 
#> acog.asom      8      9     8 
#> acog.conf      8      8     8 
#> acog.perf      8      9     8 
#> asom.conf      -      8     8 
#> asom.perf     no      -     8 
#> conf.perf     no     no     - 
#> 
#> Test for Residual Heterogeneity:
#> QE(df = 45) = 334.8358, p-val < .0001
#> 
#> Test of Moderators (coefficients 1:6):
#> QM(df = 6) = 596.7709, p-val < .0001
#> 
#> Model Results:
#> 
#>                     estimate      se     zval    pval    ci.lb    ci.ub      
#> var1.var2acog.asom    0.5671  0.0367  15.4640  <.0001   0.4953   0.6390  *** 
#> var1.var2acog.conf   -0.4888  0.0509  -9.6047  <.0001  -0.5886  -0.3891  *** 
#> var1.var2acog.perf   -0.0600  0.1408  -0.4264  0.6698  -0.3359   0.2159      
#> var1.var2asom.conf   -0.4750  0.0506  -9.3901  <.0001  -0.5741  -0.3758  *** 
#> var1.var2asom.perf   -0.1423  0.0917  -1.5527  0.1205  -0.3220   0.0373      
#> var1.var2conf.perf    0.3167  0.0847   3.7394  0.0002   0.1507   0.4827  *** 
#> 
#> ---
#> Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#>