Learn R Programming

metadat (version 1.4-0)

dat.damico2009: Studies on Topical plus Systemic Antibiotics to Prevent Respiratory Tract Infections

Description

Results from 16 studies examining the effectiveness of topical plus systemic antibiotics to prevent respiratory tract infections (RTIs).

Usage

dat.damico2009

Arguments

Format

The data frame contains the following columns:

studycharacterfirst author
yearnumericpublication year
xtnumericnumber of RTIs in the treatment group
ntnumericnumber of patients in the treatment group
xcnumericnumber of RTIs in the control group
ncnumericnumber of patients in the control group
concealnumericallocation concealment (0 = not adequate, 1 = adequate)
blindnumericblinding (0 = open, 1 = double-blind)

Concepts

medicine, odds ratios

Details

The dataset includes the results from 16 studies that examined the effectiveness of topical plus systemic antibiotics versus no prophylaxis to prevent respiratory tract infections (RTIs).

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.damico2009
dat

if (FALSE) {
### load metafor package
library(metafor)

### meta-analysis of the (log) odds ratios using the Mantel-Haenszel method
rma.mh(measure="OR", ai=xt, n1i=nt, ci=xc, n2i=nc, data=dat, digits=2)

### calculate log odds ratios and corresponding sampling variances
dat <- escalc(measure="OR", ai=xt, n1i=nt, ci=xc, n2i=nc, data=dat)

### meta-analysis using a random-effects model
res <- rma(yi, vi, data=dat, method="DL")
res
predict(res, transf=exp, digits=2)
}

Run the code above in your browser using DataLab