Learn R Programming

metadat (version 1.4-0)

dat.furukawa2003: Studies on Low Dosage Tricyclic Antidepressants for the Treatment of Depression

Description

Results on depression severity from 17 studies comparing low dosage tricyclic antidepressants (TCA) and placebo for the treatment of depression.

Usage

dat.furukawa2003

Arguments

Format

The data frame contains the following columns:

authorcharacterFirst author with information on dosage in parentheses
Neintegernumber of patients in low TCA group
Menumericdepression severity (low TCA)
Senumericstandard deviation (low TCA)
Ncintegernumber of patients in placebo group
Mcnumericdepression severity (placebo)
Scnumericstandard deviation (placebo)

Concepts

standardized mean differences

Details

Furukawa et al. (2003) carried out a systematic review comparing low dosage tricyclic antidepressants (TCA) with placebo for the treatment of depression. They reported the effect on presence/absence of depression and on depression severity at various time points. Here we focus on depression severity at four weeks. Most studies used some version of the Hamilton Depression Rating Scale, however, some studies used the Montgomery-Asberg Depression Rating Scale. Accordingly, it is not possible to pool the estimated effects directly.

This data set is used as an example in Schwarzer et al. (2015).

References

Schwarzer, G., Carpenter, J. R., & Rücker, G. (2015). Meta-analysis with R. Cham, Switzerland: Springer.

Examples

Run this code
### Show first five studies
head(dat.furukawa2003, 5)

if (FALSE) {
### Load meta package
suppressPackageStartupMessages(library("meta"))

### Use RevMan5 settings
oldset <- settings.meta("RevMan5", digits = 2)

### Conduct random effects meta-analysis with Hedges' g as effect measure
mc2 <- metacont(Ne, Me, Se, Nc, Mc, Sc, common = FALSE,
                data = dat.furukawa2003, sm = "SMD")
mc2

### Use previous settings
settings.meta(oldset)
}

Run the code above in your browser using DataLab