Learn R Programming

metadat (version 1.4-0)

dat.graves2010: Studies on the Effectiveness of Injected Cholera Vaccines

Description

Results from 17 studies on the effectiveness of injected vaccines against cholera.

Usage

dat.graves2010

Arguments

Format

The data frame contains the following columns:

studycharacterauthor/study name and publication year
ainumericnumber of cholera cases in the vaccinated group
n1inumericnumber of individuals in the vaccinated group
cinumericnumber of cholera cases in the placebo group
n2inumericnumber of individuals in the placebo group

Concepts

medicine, risk ratios, Mantel-Haenszel method

Details

Cholera is an infection caused by certain strains of the bacterium Vibrio cholerae. When untreated, mortality rates can be as high as 50-60%. Proper sanitation practices are usually effective in preventing outbreaks, but a number of oral and injectable vaccines have also been developed. The Cochrane review by Graves et al. (2010) examined the effectiveness of injectable vaccines for preventing cholera cases and death. The present dataset includes results from 17 studies that reported the number of cholera cases in vaccinated and placebo/comparison groups up to 7 months after the treatment.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.graves2010
dat

if (FALSE) {
### load metafor package
library(metafor)

### analysis using the Mantel-Haenszel method
rma.mh(measure="RR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, digits=2)
}

Run the code above in your browser using DataLab