| dat.greenland1992 | R Documentation |
Results from 16 case-control studies evaluating the impact of alcohol consumption on breast cancer risk.
dat.greenland1992
The data frame contains the following columns:
| author | character | first author |
| year | integer | publication year |
| b | numeric | adjusted log risk ratio |
| SE | numeric | standard error |
Greenland and Longecker (1992) describe a method to combine trend estimates from summarized dose-response data. A meta-analysis of 16 case-control studies evaluating the impact of alcohol consumption on breast cancer risk was used as an illustrative example. The estimates are the increase in the log relative risk of breast cancer associated with an average daily alcohol consumption of 1g.
Data are provided in Greenland and Longecker (1992), Table 3.
epidemiology, risk ratios
Guido Schwarzer, guido.schwarzer@uniklinik-freiburg.de, https://github.com/guido-s/
Greenland, S., & Longnecker, M. P. (1992). Methods for trend estimation from summarized dose-response data, with applications to meta-analysis. American Journal of Epidemiology, 135(11), 1301–1309. https://doi.org/10.1093/oxfordjournals.aje.a116237
### Show first 6 rows of the dataset
head(dat.greenland1992)
## Not run:
### Load meta package
suppressPackageStartupMessages(library(meta))
### Inverse variance method
mg <- metagen(b, SE, data = dat.greenland1992,
studlab = paste(author, year), sm = "RR",
random = FALSE, overall.hetstat = FALSE,
backtransf = FALSE)
### Overall result
print(mg, digits = 5)
### Standard error for common effect estimate
round(mg$seTE.common, 5)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.