### Show first 6 rows of the dataset
head(dat.gurusamy2011)
### Only study evaluating solvent detergent plasma
subset(dat.gurusamy2011, study == "Williamson 1999")
### Only study evaluating antithrombin III
subset(dat.gurusamy2011, study == "Baudo 1992")
if (FALSE) {
### Load netmeta package
suppressPackageStartupMessages(library("netmeta"))
### Print odds ratios and confidence limits with two digits
oldset <- settings.meta(digits = 2)
### Change appearance of confidence intervals
cilayout("(", "-")
### Transform data from long arm-based format to contrast-based
### format. Argument 'sm' has to be used for odds ratio as summary
### measure; by default the risk ratio is used in the metabin function
### called internally.
pw <- pairwise(treatment, death, n, studlab = study,
data = dat.gurusamy2011, sm = "OR")
### Conduct Mantel-Haenszel network meta-analysis (NMA)
net.MH <- netmetabin(pw, ref = "cont")
### Conduct inverse variance (IV) network meta-analysis
net.IV <- netmeta(pw, ref = "cont")
### Network graph (Mantel-Haenszel NMA)
netgraph(net.MH, seq = "optimal", col = "black", plastic = FALSE,
points = TRUE, pch = 21, cex.points = 3, col.points = "black",
bg.points = "gray", thickness = "se.fixed",
number.of.studies = TRUE)
### Full network graph (based on inverse variance method, including
### study comparing Antithrombin III with Control/Placebo)
netgraph(net.IV,
seq = "optimal", col = "black", plastic = FALSE,
points = TRUE, pch = 21, cex.points = 3, col.points = "black",
bg.points = "gray", thickness = "se.fixed",
number.of.studies = TRUE)
### Compare results for Mantel-Haenszel and IV NMA
forest(netbind(net.MH, net.IV,
random = FALSE, name = c("MH NMA", "IV NMA")))
### Show results for Mantel-Haenszel NMA
net.MH
forest(net.MH)
### League table with network estimates in lower triangle and direct
### estimates in upper triangle
netleague(net.MH)
### Assess inconsistency
print(netsplit(net.MH), show = "both", ci = TRUE, overall = FALSE,
nchar.trts = 6)
### Use previous settings
settings.meta(oldset)
}
Run the code above in your browser using DataLab