Learn R Programming

metadat (version 1.4-0)

dat.hannum2020: Studies Comparing Objective and Subjective Olfactory Loss in COVID-19 Patients

Description

Results from 35 studies measuring olfactory loss in COVID-19 patients using either objective or subjective measures.

Usage

dat.hannum2020

Arguments

Format

The data frame contains the following columns:

authorNamecharacter(first) author of study
DOIcharacterarticle DOI number
ninumericnumber of Covid-19 positive patients in the study
xinumericnumber of Covid-19 positive patients in the study with olfactory loss
percentOlfactoryLossnumericpercent of the sample with olfactory loss
objectivitycharacterobjective or subjective measure used
measuredcharacteroutcome measure
testTypecharactertype of test used
countrycharactercountry where patients were treated
patientTypecharactertype of patient information and location where being treated

Concepts

medicine, covid-19, proportions

Details

One of the symptoms of COVID-19 infection is olfactory loss (loss of smell) either recently acquired anosmia (complete loss of smell) or hyposmia (partial loss of smell). One challenge to reaching this symptom is the wide range of reported prevalence for this symptom ranging from 5 percent to 98 percent. In this dataset studies were grouped into one of two groups based on the type of method used to measure smell loss (either subjective measures, such as self-reported smell loss, or objective measures using rated stimuli).

References

Hannum, M. E., Ramirez, V. A., Lipson, S. J., Herriman, R. D., Toskala, A. K., Lin, C., Joseph, P. V., & Reed, D. R. (2020). Objective sensory testing methods reveal a higher prevalence of olfactory loss in COVID-19 positive patients compared to subjective methods: A systematic review and meta-analysis. Chemical Senses, 45(9), 865--874. https://doi.org/10.1093/chemse/bjaa064

Examples

Run this code
# copy data into 'dat' and examine data
dat <- dat.hannum2020
dat

if (FALSE) {
# load metafor package
library(metafor)

# compute effect size
dat <- escalc(measure="PR", xi=xi, ni=ni, data=dat)

# split data into objective and subjective datasets
dat_split <- split(dat, dat$objectivity)
dat_objective <- dat_split[["Objective"]]
dat_subjective <- dat_split[["Subjective"]]

# random-effects model all studies
res_all <- rma(yi, vi, data=dat)
print(res_all, digits=2)

# random-effects model objective
res_objective <- rma(yi, vi, data=dat_objective)
print(res_objective, digits=2)

# random-effects model subjective
res_subjective <- rma(yi, vi, data=dat_subjective)
print(res_subjective, digits=2)
}

Run the code above in your browser using DataLab