Learn R Programming

metadat (version 1.4-0)

dat.hartmannboyce2018: Studies on the Effectiveness of Nicotine Replacement Therapy for Smoking Cessation

Description

Results from 133 studies examining the effectiveness of nicotine replacement therapy (NRT) for smoking cessation at 6+ months of follow-up.

Usage

dat.hartmannboyce2018

Arguments

Format

The data frame contains the following columns:

studynumericstudy identifier
x.nrtnumericnumber of participants in the NRT group who were abstinent at the follow-up
n.nrtnumericnumber of participants in the NRT group
x.ctrlnumericnumber of participants in the control group who were abstinent at the follow-up
n.ctrlnumericnumber of participants in the control group
treatmentcharactertype of NRT provided in the treatment group

Concepts

medicine, smoking, risk ratios, Mantel-Haenszel method

Details

The dataset includes the results from 133 studies examining the effectiveness of nicotine replacement therapy (NRT) for smoking cessation. The results given in this dataset pertain to abstinence at 6+ months of follow-up. NRT was provided to participants in the treatment groups in various forms as indicated by the treatment variable (e.g., gum, patch, inhalator). Note that the dataset includes 136 rows, since a few studies included multiple treatments.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.hartmannboyce2018
head(dat, 10)

if (FALSE) {
### load metafor package
library(metafor)

### turn treatment into a factor with the desired ordering
dat$treatment <- factor(dat$treatment, levels=unique(dat$treatment))

### meta-analysis per treatment using the M-H method
lapply(split(dat, dat$treatment), function(x)
       rma.mh(measure="RR", ai=x.nrt,  n1i=n.nrt,
                            ci=x.ctrl, n2i=n.ctrl, data=x, digits=2))

### all combined
rma.mh(measure="RR", ai=x.nrt,  n1i=n.nrt,
                     ci=x.ctrl, n2i=n.ctrl, data=dat, digits=2)
}

Run the code above in your browser using DataLab