dat.higgins2008.RdResults on clinical improvement after therapy from 17 trials evaluating haloperidol in patients with schizophrenia.
dat.higgins2008The data frame contains the following columns:
| author | character | study label |
| resp.halo | integer | number of responders (haloperidol group) |
| fail.halo | integer | number of failures (haloperidol group) |
| miss.halo | integer | number of missing observations (haloperidol group) |
| resp.plac | integer | number of responders (placebo group) |
| fail.plac | integer | number of failures (placebo group) |
| miss.plac | integer | number of missing observations (placebo group) |
Higgins et al. (2008) suggested several imputation methods for the meta-analysis of binary outcomes with missing data. The example data set with 17 trials comes originally from a Cochrane review comparing haloperidol with placebo for the treatment of schizophrenia. While the antipsychotic benefits of haloperidol were identified in the 1950s, trials in this patient population are prone to high proportions of missing outcome data, often due to insufficient compliance with randomized controlled trial protocols.
The outcome is clinical improvement after therapy. For each study, the number of responders, failures, and missing observations are available.
Higgins, J. P. T., White, I. R., & Wood, A. M. (2008). Imputation methods for missing outcome data in meta-analysis of clinical trials. Clinical Trials, 5(3), 225–239. https://doi.org/10.1177/1740774508091600
psychiatry, odds ratios, missing data
### Show first five studies
head(dat.higgins2008, 5)
#> author resp.halo fail.halo miss.halo resp.plac fail.plac miss.plac
#> 1 Avanitis 25 25 2 18 33 0
#> 2 Beasley 29 18 22 20 14 34
#> 3 Bechelli 12 17 1 2 28 1
#> 4 Borison 3 9 0 0 12 0
#> 5 Chouinard 10 11 0 3 19 0
### Load metasens package
suppressPackageStartupMessages(library(metasens))
### Print odds ratios and confidence limits with three digits
oldset <- settings.meta(digits = 3)
### Conduct common effect meta-analysis of available data
m <- metabin(resp.halo, resp.halo + fail.halo,
resp.plac, resp.plac + fail.plac,
data = dat.higgins2008, studlab = author,
sm = "OR", method = "Inverse", random = FALSE,
label.e = "Haloperidol", label.c = "Placebo",
label.left = "Favours placebo",
label.right = "Favours haloperidol")
### Best case scenario for haloperidol
m.b <- metamiss(m, miss.halo, miss.plac,
method.miss = "b", small.values = "undesirable")
### Worst case scenario for haloperidol
m.w <- metamiss(m, miss.halo, miss.plac,
method.miss = "w", small.values = "undesirable")
### Forest plot
m.sens <- metamerge(m, m.b, text.pooled2 = "Best case scenario")
m.sens <- metamerge(m.sens, m.w, text.pooled2 = "Worst case scenario")
forest(m.sens)