Learn R Programming

metadat (version 1.4-0)

dat.landenberger2005: Studies on the Effectiveness of CBT for Reducing Recidivism

Description

Results from 58 studies on the effectiveness of cognitive-behavioral therapy (CBT) for reducing recidivism in juvenile and adult offenders.

Usage

dat.landenberger2005

Arguments

Format

The data frame contains the following columns:

studycharacter(first) author and year
pubtypecharacterpublication type (book chapter, journal article, report, or thesis)
countrycharactercountry where study was carried out (Canada, New Zealand, UK, or USA)
designcharacterstudy design (matched groups, nonequivalent groups, or randomized trial)
programcharacterpurpose of setting up the CBT program (for demonstration, practice, or research purposes)
settingcharactertreatment setting (community or prison)
designprobcharacterindication of study design problems (no, favors the control group, or favors the treatment group)
n.ctrl.recnumericnumber of recidivists in the control group
n.ctrl.nonnumericnumber of non-recidivists in the control group
n.cbt.recnumericnumber of recidivists in the CBT group
n.cbt.nonnumericnumber of non-recidivists in the CBT group
intervalnumericrecidivism interval (in months)
groupnumericstudy group (adults or juveniles)
agenumericmean age of the study group
malenumericpercentage of males in the study group
minoritynumericpercentage of minorities in the study group
lengthnumerictreatment length (in weeks)
sessionsnumericnumber of CBT sessions per week
hrs_weeknumerictreatment hours per week
hrs_totalnumerictotal hours of treatment
cbt.cogskillscharacterCBT component: cognitive skills (yes, no)
cbt.cogrestructcharacterCBT component: cognitive restructuring (yes, no)
cbt.intpprbsolvcharacterCBT component: interpersonal problem solving (yes, no)
cbt.socskillscharacterCBT component: social skills (yes, no)
cbt.angerctrlcharacterCBT component: anger control (yes, no)
cbt.victimimpactcharacterCBT component: victim impact (yes, no)
cbt.subabusecharacterCBT component: substance abuse (yes, no)
cbt.behavmodcharacterCBT component: behavior modification (yes, no)
cbt.relapseprevcharacterCBT component: relapse prevention (yes, no)
cbt.moralrsngcharacterCBT component: moral reasoning (yes, no)
cbt.roletakingcharacterCBT component: role taking (yes, no)
cbt.othercharacterCBT component: other (yes, no)

Concepts

psychology, criminology, odds ratios, meta-regression

Details

Landenberger and Lipsey (2005) conducted a meta-analysis of 58 experimental and quasi-experimental studies of the effects of cognitive-behavioral therapy (CBT) on the recidivism rates of adult and juvenile offenders (see also Lipsey et al., 2007). The present dataset includes the results of these studies and a range of potential moderator variables to identify factors associated with variation in treatment effects.

References

Landenberger, N. A., & Lipsey, M. W. (2005). The positive effects of cognitive-behavioral programs for offenders: A meta-analysis of factors associated with effective treatment. Journal of Experimental Criminology, 1, 451--476. https://doi.org/10.1007/s11292-005-3541-7

Lipsey, M. W., Landenberger, N. A., & Wilson, S. J. (2007). Effects of cognitive-behavioral programs for criminal offenders. Campbell Systematic Reviews, 3(1), 1--27. https://doi.org/10.4073/csr.2007.6

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.landenberger2005
head(dat)

if (FALSE) {
### load metafor package
library(metafor)

### calculate log odds ratios (for non-recidivism in CBT vs. control groups) and sampling variances
dat <- escalc(measure="OR", ai=n.cbt.non, bi=n.cbt.rec, ci=n.ctrl.non, di=n.ctrl.rec, data=dat)

### fit random-effects model
res <- rma(yi, vi, data=dat)
res

### estimated average OR and corresponding 95% CI/PI
predict(res, transf=exp, digits=2)

### examine if number of treatment sessions per week is a potential moderator
res <- rma(yi, vi, mods = ~ sessions, data=dat)
res

### predicted ORs for 1, 2, 5, or 10 sessions per week
predict(res, newmods=c(1,2,5,10), transf=exp, digits=2)
}

Run the code above in your browser using DataLab