Learn R Programming

metadat (version 1.4-0)

dat.laopaiboon2015: Studies on the Effectiveness of Azithromycin for Treating Lower Respiratory Tract Infections

Description

Results from 15 studies on the effectiveness of azithromycin versus amoxycillin or amoxycillin/clavulanic acid (amoxyclav) in the treatment of acute lower respiratory tract infections.

Usage

dat.laopaiboon2015

Arguments

Format

The data frame contains the following columns:

authorcharacterauthor(s)
yearnumericpublication year
ainumericnumber of clinical failures in the group treated with azithromycin
n1inumericnumber of patients in the group treated with azithromycin
cinumericnumber of clinical failures in the group treated with amoxycillin or amoxyclav
n2inumericnumber of patients in the group treated with amoxycillin or amoxyclav
agecharacterwhether the trial included adults or children
diag.abnumerictrial included patients with a diagnosis of acute bacterial bronchitis
diag.cbnumerictrial included patients with a diagnosis of chronic bronchitis with acute exacerbation
diag.pnnumerictrial included patients with a diagnosis of pneumonia
ctrlcharacterantibiotic in control group (amoxycillin or amoxyclav)

Concepts

medicine, risk ratios

Details

Azithromycin is an antibiotic useful for the treatment of a number of bacterial infections. Laopaiboon et al. (2015) conducted a meta-analysis of trials comparing the effectiveness of azithromycin versus amoxycillin or amoxycillin/clavulanic acid (amoxyclav) in the treatment of acute lower respiratory tract infections, including acute bacterial bronchitis, acute exacerbations of chronic bronchitis, and pneumonia. The results from 15 trials are included in this dataset.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.laopaiboon2015
dat

if (FALSE) {
### load metafor package
library(metafor)

### analysis using the Mantel-Haenszel method
rma.mh(measure="RR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, digits=3)

### calculate log risk ratios and corresponding sampling variances
dat <- escalc(measure="RR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat)

### random-effects model
res <- rma(yi, vi, data=dat)
res

### average risk ratio with 95% CI
predict(res, transf=exp)
}

Run the code above in your browser using DataLab