Learn R Programming

metadat (version 1.4-0)

dat.lau1992: Studies on Intravenous Streptokinase for Acute Myocardial Infarction

Description

Results from 33 trials comparing intravenous streptokinase versus placebo or no therapy in patients who had been hospitalized for acute myocardial infarction.

Usage

dat.lau1992

Arguments

Format

The data frame contains the following columns:

trialcharactertrial name
yearnumericpublication year
ainumericnumber of deaths in the streptokinase group
n1inumericnumber of patients in the streptokinase group
cinumericnumber of deaths in the control group
n2inumericnumber of patients in the control group

Concepts

medicine, cardiology, odds ratios, cumulative meta-analysis

Details

In the paper by Lau et al. (1992), the data are used to illustrate the idea of a cumulative meta-analysis, where the results are updated as each trial is added to the dataset. See ‘Examples’ for code that replicates the results and shows corresponding forest plots.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.lau1992
dat

if (FALSE) {
### load metafor package
library(metafor)

### meta-analysis of log odds ratios using the MH method
res <- rma.mh(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, slab=trial)
print(res, digits=2)

### forest plot
forest(res, xlim=c(-11,9), atransf=exp, at=log(c(0.01, 0.1, 1, 10, 100)),
       ilab=dat$year, ilab.xpos=-7)
text(-7, 35, "Year", font=2)

### cumulative meta-analysis
sav <- cumul(res)

### forest plot of the cumulative results
forest(sav, xlim=c(-5,4), atransf=exp, at=log(c(0.1, 0.5, 1, 2, 10)),
       ilab=dat$year, ilab.xpos=-3)
text(-3, 35, "Year", font=2)
id <- c(4, 8, 15, 33) # rows for which the z/p-values should be shown (as in Lau et al., 1992)
text(1.1, (res$k:1)[id], paste0("z = ", fmtx(sav$zval[id], digits=2),
                                fmtp(sav$pval[id], pname=", p", equal=TRUE, sep=TRUE, add0=TRUE)))
}

Run the code above in your browser using DataLab