Learn R Programming

metadat (version 1.4-0)

dat.li2007: Studies on the Effectiveness of Intravenous Magnesium in Acute Myocardial Infarction

Description

Results from 22 trials examining the effectiveness of intravenous magnesium in the prevention of death following acute myocardial infarction.

Usage

dat.li2007

Arguments

Format

The data frame contains the following columns:

idnumerictrial id number
studycharacterfirst author or trial name
yearnumericpublication year
ainumericnumber of deaths in the magnesium group
n1inumericnumber of patients in the magnesium group
cinumericnumber of deaths in the control group
n2inumericnumber of patients in the control group

Concepts

medicine, cardiology, odds ratios, publication bias

Details

The dataset includes the results from 22 randomized clinical trials that examined the effectiveness of intravenous magnesium in the prevention of death following acute myocardial infarction. It is similar to the dataset dat.egger2001, with some slight differences in the included trials and data used.

See Also

dat.egger2001

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.li2007
dat

if (FALSE) {
### load metafor package
library(metafor)

### meta-analysis of all trials except ISIS-4
res <- rma(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, method="EE", subset=-14)
print(res, digits=2)
predict(res, transf=exp, digits=2)

### meta-analysis of all trials including ISIS-4
res <- rma(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, method="EE")
print(res, digits=2)
predict(res, transf=exp, digits=2)

### contour-enhanced funnel plot centered at 0
funnel(res, refline=0, level=c(90, 95, 99), shade=c("white", "gray", "darkgray"))
}

Run the code above in your browser using DataLab