Learn R Programming

metadat (version 1.4-0)

dat.linde2005: Studies on the Effectiveness of St. John's Wort for Treating Depression

Description

Results from 26 studies on the effectiveness of Hypericum perforatum extracts (St. John's wort) for treating depression.

Usage

dat.linde2005

Arguments

Format

The data frame contains the following columns:

idnumericstudy number
studycharacterstudy author(s)
yearnumericpublication year
countrycharacterstudy location
ninumerictotal sample size
majornumericsample restricted to patients who met criteria for major depression
baselinenumericHRSD baseline score
versionnumericHRSD version (17 or 21 items)
durationnumericstudy duration (in weeks)
prepcharacterHypericum extract preparation
dosagenumericdosage (in mg)
responsenumericdefinition of response (see ‘Details’)
ainumericnumber of responses in treatment group
n1inumericnumber of patients in treatment group
cinumericnumber of responses in placebo group
n2inumericnumber of patients in placebo group
groupnumericstratification variable used by the authors (see ‘Details’)

Concepts

medicine, psychiatry, risk ratios

Details

The dataset includes the results from 26 double-blind placebo-controlled trials on the effectiveness of Hypericum perforatum extracts (St. John's wort) for treating depression (note that 2 studies did not provide sufficient response information).

Data were extracted from Table 1 and Figure 3 from Linde et al. (2005). For study duration, the assessment week (instead of the total study duration) was coded for Philipp et al. (1999) and Montgomery et al. (2000). For dosage, the midpoint was coded when a range of values was given.

The definition of what constitutes a response differed across studies and is coded as follows:

  1. HRSD score reduction of at least 50% or HRSD score after therapy <10,

  2. HRSD reduction of at least 50%,

  3. based on HRSD scale but exact definition not reported,

  4. global patient assessment of efficacy,

  5. at least ‘much improved’ on the Clinical Global Impression sub-scale for global improvement.

The group variable corresponds to the variable used by Linde et al. (2005) to stratify their analyses and is coded as follows:

  1. smaller trials restricted to major depression,

  2. larger trials restricted to major depression,

  3. smaller trials not restricted to major depression,

  4. larger trials not restricted to major depression.

References

Viechtbauer, W. (2007). Accounting for heterogeneity via random-effects models and moderator analyses in meta-analysis. Zeitschrift für Psychologie / Journal of Psychology, 215(2), 104--121. https://doi.org/10.1027/0044-3409.215.2.104

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.linde2005
head(dat)

if (FALSE) {
### load metafor package
library(metafor)

### remove studies with no response information and study with no responses in either group
dat <- dat[-c(5,6,26),]

### calculate log risk ratios and corresponding sampling variances
dat <- escalc(measure="RR", ai=ai, ci=ci, n1i=n1i, n2i=n2i, data=dat)
head(dat)

### meta-analysis of the log risk ratios using a random-effects model
res <- rma(yi, vi, data=dat, method="DL")
res

### mixed-effects meta-regression model with stratification variable
res <- rma(yi, vi, mods = ~ 0 + factor(group), data=dat, method="DL")
res

### predicted average risk ratio for each level of the stratification variable
predict(res, newmods=diag(4), transf=exp, digits=2)
}

Run the code above in your browser using DataLab