Learn R Programming

metadat (version 1.4-0)

dat.mccurdy2020: Studies on the Generation Effect

Description

Results from 126 articles that examined the so-called ‘generation effect’.

Usage

dat.mccurdy2020

Arguments

Format

The data frame contains the following columns:

articlenumericarticle identifier
experimentcharacterexperiment (within article) identifier
samplenumericsample (within experiment) identifier
idnumericrow identifier
pairingnumericidentifier to indicate paired conditions within experiments
yinumericmean recall rate for the condition
vinumericcorresponding sampling variance
ninumericnumber of participants for the condition
stimulinumericnumber of stimuli for the condition
conditionfactorcondition (‘read’ or ‘generate’)
gen_difficultyfactorgeneration difficulty (‘low’ or ‘high’)
manip_typefactormanipulation type of the generate versus read condition (using a ‘within’ or ‘between’ subjects design)
present_stylefactorpresentation style (‘mixed’ or ‘pure’ list presentation)
word_statusfactorword status (‘words’, ‘non-words’, or ‘numbers’)
memory_testfactormemory test (‘recognition’, ‘cued recall’, or ‘free recall’)
memory_typefactormemory type (‘item’, ‘source’, ‘font color’, ‘font type’, ‘order’, ‘cue word’, ‘background color’, or ‘location’)
gen_constraintfactorgeneration constraint (‘low’, ‘medium’, or ‘high’)
learning_typefactorlearning type (‘incidental’ or ‘intentional’)
stimuli_relationfactorstimuli relation (‘semantic’, ‘category’, ‘antonym’, ‘synonym’, ‘rhyme’, ‘compound words’, ‘definitions’, or ‘unrelated’)
gen_modefactorgeneration mode (‘verbal/speaking’, ‘covert/thinking’, or ‘writing/typing’)
gen_taskfactorgeneration task (‘anagram’, ‘letter transposition’, ‘word fragment’, ‘sentence completion’, ‘word stem’, ‘calculation’, or ‘cue only’)
attentionfactorattention (‘divided’ or ‘full’)
pacingfactorpacing (‘self-paced’ or ‘timed’)
filler_taskfactorfiller task (‘yes’ or ‘no’)
age_grpfactorage group (‘younger’ or ‘older’ adults)
retention_delayfactorretention delay (‘immediate’, ‘short’, or ‘long’)

Concepts

psychology, memory, proportions, raw means, multilevel models, cluster-robust inference

Details

The generation effect is the memory benefit for self-generated compared with read or experimenter-provided information (Jacoby, 1978; Slamecka & Graf, 1978). In a typical study, participants are presented with a list of stimuli (usually words or word pairs). For half of the stimuli, participants self-generate a target word (e.g., open–cl____), while for the other half, participants simply read an intact target word (e.g., above–below). On a later memory test for the target words, the common finding is that self-generated words are better remembered than read words (i.e., the generation effect).

Although several theories have been proposed to explain the generation effect, there is still some debate on the underlying memory mechanism(s) contributing to this phenomenon. The meta-analysis by McCurdy et al. (2020) translated various theories on the generation effect into hypotheses that could then be tested in moderator analyses based on a dataset containing 126 articles, 310 experiments, and 1653 mean recall estimates collected under various conditions.

Detailed explanations of the various variables coded (and how these can be used to test various hypotheses regarding the generation effect) can be found in the article. The most important variable is condition, which denotes whether a particular row of the dataset corresponds to the results of a ‘read’ or a ‘generate’ condition.

The data structure is quite complex. Articles may have reported the findings from multiple experiments involving one or multiple samples that were examined under various conditions. The pairing variable indicates which rows of the dataset represent a pairing of a read condition with one or multiple corresponding generate conditions within an experiment. A pairing may involve the same sample of subjects (when using a within-subjects design for comparing the conditions) or different samples (when using a between-subjects design).

References

Slamecka, N. J., & Graf, P. (1978). The generation effect: Delineation of a phenomenon. Journal of Experimental Psychology: Human Learning and Memory, 4(6), 592--604. https://doi.org/10.1037/0278-7393.4.6.592

Jacoby, L. L. (1978). On interpreting the effects of repetition: Solving a problem versus remembering a solution. Journal of Verbal Learning and Verbal Behavior, 17(6), 649--668. https://doi.org/10.1016/S0022-5371(78)90393-6

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.mccurdy2020
head(dat)

if (FALSE) {
### load metafor package
library(metafor)

### fit multilevel mixed-effects meta-regression model
res <- rma.mv(yi, vi, mods = ~ condition,
              random = list(~ 1 | article/experiment/sample/id, ~ 1 | pairing),
              data=dat, sparse=TRUE, digits=3)
res

### proportion of total amount of heterogeneity due to each component
data.frame(source=res$s.names, sigma2=round(res$sigma2, 3),
   prop=round(res$sigma2 / sum(res$sigma2), 2))

### apply cluster-robust inference methods
sav <- robust(res, cluster=article, clubSandwich=TRUE)
sav

### estimated average recall rate in read and generate conditions
predict(sav, newmods = c(0,1), digits=3)
}

Run the code above in your browser using DataLab