Results from 37 trials evaluating non-steroidal anti-inflammatory drugs (NSAIDS) in patients with acute pain.

dat.moore1998

Format

The data frame contains the following columns:

idintegerstudy ID
authorcharacterfirst author
yearintegerpublication year
Eeintegernumber of treatment successes (NSAIDS group)
Neintegernumber of patients (NSAIDS group)
Ecintegernumber of treatment successes (control group)
Ncintegernumber of patients (control group)
nonenglishintegernon-English publication
medlineintegerlisted in Medline
greyintegergrey literature
samecontintegersame control group
journalcharacterjournal

Details

Moore et al. (1998) conducted a systematic review of 37 randomized placebo-controlled trials on the effectiveness and safety of topical non-steroidal anti-inflammatory drugs (NSAIDS) in acute pain. The main outcome was treatment success, defined as a reduction in pain of at least 50%.

This data set is used as an example in Schwarzer et al. (2015).

Moore, R. A., Tramèr, M. R., Carroll, D., Wiffen, P. J., & McQuay, H. J. (1998). Quantitive systematic review of topically applied non-steroidal anti-inflammatory drugs. British Medical Journal, 316(7128), 333–338. https://doi.org/10.1136/bmj.316.7128.333

References

Schwarzer, G., Carpenter, J. R., & Rücker, G. (2015). Meta-analysis with R. Cham, Switzerland: Springer.

Concepts

medicine, odds ratios, publication bias

Examples

### Show first five studies
head(dat.moore1998, 5)
#>   id     author year Ee  Ne Ec  Nc nonenglish medline grey samecont
#> 1  1 Airaksinen 1993 24  29 14  27          0       1    0        0
#> 2  2   Akermark 1990 10  23  3  24          0       1    0        0
#> 3  3       Aoki 1984 56  84 33  84          1       0    0        1
#> 4  4       Aoki 1984 41  84 33  84          1       0    0        1
#> 5  5    Auclair 1989 69 123 54 116          0       0    0        0
#>                                    journal
#> 1 Int J of Clin Pharm Therapy & Toxicology
#> 2                 Int J of Sports Medicine
#> 3     Japanese Pharmacology & Therapeutics
#> 4     Japanese Pharmacology & Therapeutics
#> 5                            Curr Ther Res

### Load meta package
suppressPackageStartupMessages(library(meta))

### Conduct meta-analysis
m <- metabin(Ee, Ne, Ec, Nc, data = dat.moore1998,
  sm = "OR", studlab = id,
  label.e = "NSAIDS", label.c = "Placebo")

### Funnel plot
fun <- funnel(m, type = "contour",
  random = FALSE, pch = 16)
legend(0.25, 1.25, bty = "n",
  legend = fun$text.contour, fill = fun$col.contour)