Learn R Programming

metadat (version 1.4-0)

dat.nakagawa2007: Assessing the Function of House Sparrows' Bib Size Using a Flexible Meta-Analysis Method

Description

A meta-analysis on the association between the size of a male's bib and their social status in house sparrows (Passer domesticus).

Usage

dat.nakagawa2007

Arguments

Format

The data frame contains the following columns:

StudyIDcharacteridentity of primary study
Placecharacterlocation of study population
Correlationnumericcorrelation coefficient
SampleSizeintegersample size of population

Author

Daniel Noble, daniel.noble@anu.edu.au

Concepts

ecology, correlation coefficients

Details

Each study measures the association between a sparrows bib size and its social status. Effects are quantified as correlation coefficients.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.nakagawa2007
dat

if (FALSE) {
### load metafor package
library(metafor)

### calculate Zr
dat <- escalc(measure="ZCOR", ri=Correlation, ni=SampleSize, data=dat)

### fit meta-analytic model
res <- rma.mv(yi, vi, random = ~ 1 | StudyID, data=dat)
res
}

Run the code above in your browser using DataLab