Learn R Programming

metadat (version 1.4-0)

dat.nielweise2008: Studies on Anti-Infective-Treated Central Venous Catheters for Prevention of Catheter-Related Bloodstream Infections

Description

Results from 18 studies comparing the risk of catheter-related bloodstream infection when using anti-infective-treated versus standard catheters for total parenteral nutrition or chemotherapy.

Usage

dat.nielweise2008

Arguments

Format

The data frame contains the following columns:

studynumericstudy number
authorscharacterstudy authors
yearnumericpublication year
x1inumericnumber of CRBSIs in patients receiving an anti-infective catheter
t1inumerictotal number of catheter days for patients receiving an anti-infective catheter
x2inumericnumber of CRBSIs in patients receiving a standard catheter
t2inumerictotal number of catheter days for patients receiving a standard catheter

Concepts

medicine, incidence rates, generalized linear models

Details

The use of a central venous catheter may lead to a catheter-related bloodstream infection (CRBSI), which in turn increases the risk of morbidity and mortality. Anti-infective-treated catheters have been developed that are meant to reduce the risk of CRBSIs. Niel-Weise et al. (2008) conducted a meta-analysis of studies comparing infection risk when using anti-infective-treated versus standard catheters for total parenteral nutrition or chemotherapy. The results from 9 such studies are included in this dataset.

The dataset was used in the article by Stijnen et al. (2010) to illustrate various generalized linear mixed-effects models for the meta-analysis of incidence rates and incidence rate ratios (see ‘References’).

References

Stijnen, T., Hamza, T. H., & Ozdemir, P. (2010). Random effects meta-analysis of event outcome in the framework of the generalized linear mixed model with applications in sparse data. Statistics in Medicine, 29(29), 3046--3067. https://doi.org/10.1002/sim.4040

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.nielweise2008
dat

if (FALSE) {
### load metafor package
library(metafor)

### standard (inverse-variance) random-effects model
res <- rma(measure="IRR", x1i=x1i, t1i=t1i, x2i=x2i, t2i=t2i, data=dat)
print(res, digits=3)
predict(res, transf=exp, digits=2)

### random-effects conditional Poisson model
res <- rma.glmm(measure="IRR", x1i=x1i, t1i=t1i, x2i=x2i, t2i=t2i, data=dat, model="CM.EL")
print(res, digits=3)
predict(res, transf=exp, digits=2)
}

Run the code above in your browser using DataLab