Learn R Programming

metadat (version 1.4-0)

dat.normand1999: Studies on the Length of Hospital Stay of Stroke Patients

Description

Results from 9 studies on the length of the hospital stay of stroke patients under specialized care and under conventional/routine (non-specialist) care.

Usage

dat.normand1999

Arguments

Format

The data frame contains the following columns:

studynumericstudy number
sourcecharactersource of data
n1inumericnumber of patients under specialized care
m1inumericmean length of stay (in days) under specialized care
sd1inumericstandard deviation of the length of stay under specialized care
n2inumericnumber of patients under routine care
m2inumericmean length of stay (in days) under routine care
sd2inumericstandard deviation of the length of stay under routine care

Concepts

medicine, raw mean differences, standardized mean differences

Details

The 9 studies provide data in terms of the mean length of the hospital stay (in days) of stroke patients under specialized care and under conventional/routine (non-specialist) care. The goal of the meta-analysis was to examine the hypothesis whether specialist stroke unit care will result in a shorter length of hospitalization compared to routine management.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.normand1999
dat

if (FALSE) {
### load metafor package
library(metafor)

### calculate mean differences and corresponding sampling variances
dat <- escalc(measure="MD", m1i=m1i, sd1i=sd1i, n1i=n1i, m2i=m2i, sd2i=sd2i, n2i=n2i, data=dat)
dat

### meta-analysis of mean differences using a random-effects model
res <- rma(yi, vi, data=dat)
res

### meta-analysis of standardized mean differences using a random-effects model
res <- rma(measure="SMD", m1i=m1i, sd1i=sd1i, n1i=n1i, m2i=m2i, sd2i=sd2i, n2i=n2i,
           data=dat, slab=source)
res

### draw forest plot
forest(res, xlim=c(-7,5), alim=c(-3,1), header="Study/Source")

### calculate (log transformed) ratios of means and corresponding sampling variances
dat <- escalc(measure="ROM", m1i=m1i, sd1i=sd1i, n1i=n1i, m2i=m2i, sd2i=sd2i, n2i=n2i, data=dat)
dat

### meta-analysis of the (log transformed) ratios of means using a random-effects model
res <- rma(yi, vi, data=dat)
res
predict(res, transf=exp, digits=2)
}

Run the code above in your browser using DataLab