dat.quan2000.RdResults from 11 studies evaluating pharmacotherapy in patients with hypertension.
dat.quan2000The data frame contains the following columns:
| study | character | study label |
| Ee | integer | fatal cerebrovascular events (pharmacotherapy) |
| Ne | integer | number of patients (pharmacotherapy) |
| Ec | integer | fatal cerebrovascular events (control) |
| Nc | integer | number of patients (control) |
Quan et al. (2000) conducted a Cochrane Review to evaluate whether the benefit of treating hypertension in women differed between younger and older women, as well as between white and African American women. In the systematic review, the Peto method was used for pooling. The primary outcome was the occurrence of fatal cerebrovascular events, a rare event in hypertension. The dataset contains the subgroup of women older than 55 years.
This data set is used as an example in Schwarzer et al. (2015).
Quan, A. P., Kerlikowske, K., Gueyffier, F., Boissel, J.-P., & INDANA Investigators (2010). Pharmacotherapy for hypertension in women of different races. Cochrane Database of Systematic Reviews, 2, CD002146. https://doi.org/10.1002/14651858.cd002146
Schwarzer, G., Carpenter, J. R., & Rücker, G. (2015). Meta-analysis with R. Cham, Switzerland: Springer.
medicine, cardiology, Peto's method
### Show first five studies
head(dat.quan2000, 5)
#> study Ee Ne Ec Nc
#> 1 Australian 0 300 1 295
#> 2 CASTEL 7 232 8 192
#> 3 Coope 3 297 6 314
#> 4 EWPHE 17 287 21 299
#> 5 HDFP 11 984 19 938
### Load meta package
suppressPackageStartupMessages(library(meta))
### Use RevMan 5 settings
oldset <- settings.meta("RevMan5")
### Conduct meta-analyis with Peto method
m <- metabin(Ee, Ne, Ec, Nc, sm = "OR", method = "Peto",
data = dat.quan2000, studlab = study, random = FALSE)
m
#> Number of studies: k = 11
#> Number of observations: o = 17604 (o.e = 8969, o.c = 8635)
#> Number of events: e = 194
#>
#> OR 95%-CI z p-value
#> Fixed effect model 0.75 [0.56, 1.00] -1.99 0.0465
#>
#> Quantifying heterogeneity (with 95%-CIs):
#> tau^2 = 0 [0.000, 0.604]; tau = 0 [0.0000, 0.7770]
#> I^2 = 0% [0%, 60%]; H = 1.00 [1.00, 1.59]
#>
#> Test of heterogeneity:
#> Q d.f. p-value
#> 9.16 10 0.5173
#>
#> Details of meta-analysis methods:
#> - Peto method (fixed effect model)
#> - DerSimonian-Laird estimator for tau^2
#> - Jackson method for confidence interval of tau^2 and tau
#> - Calculation of I^2 based on Q
### Use previous settings
settings.meta(oldset)