| dat.rivera2025 | R Documentation |
Studies evaluating the diagnostic accuracy of the IAF and 3Q-TMD instruments based on the reference tests RDC and DC-TMD for the diagnosis of temporomandibular disorders.
dat.rivera2025
The data frame contains the following columns:
| Author | character | study author(s) |
| Year | integer | year of the study |
| Title | character | title of the article |
| DOI | character | DOI for the article |
| TP | integer | number of true positives |
| FP | integer | number of false positives |
| FN | integer | number of false negatives |
| TN | integer | number of true negatives |
| Sensitivity | numeric | sensitivity |
| Specificity | numeric | specificity |
| PPV | numeric | positive predictive value |
| NPV | numeric | negative predictive value |
| Sample.size | integer | sample size |
| n1 | integer | number of people with the disease |
| n2 | integer | number of people without the disease |
| Prevalence | numeric | prevalence |
| AUC | numeric | area under the curve |
| SampleID | character | sample identifier |
Results of 10 studies that evaluated the diagnostic accuracy of the IAF and 3Q-TMD instruments based on the reference tests RDC and DC-TMD were included. The search period ranged from 1992 to April 2022 in six electronic databases. Two independent reviewers selected the studies. Risk of bias and applicability were assessed using the QUADAS 2 instrument.
medicine, dentistry, diagnostic accuracy studies
Álvarez-Vaz, Ramón, ramon.alvarez@fcea.edu.uy
Rivera, Hugo Daniel; Álvarez-Vaz, Ramón, 2025, "Conjunto de datos de: Comparación de dos pruebas diagnósticas para la detección de trastornos témporomandibulares. Una revisión sistemática y metaanálisis.", https://doi.org/10.60895/redata/YIEGLZ, Repositorio de datos abiertos de investigación de Uruguay, V1
Rivera, H. D., Rodríguez, C. I., Álvarez Vaz, R., & Kreiner, M. (2025). Comparison of two diagnostic tests for the detection of temporomandibular disorders: A systematic review and meta-analysis. Odontoestomatología, 27(45). https://doi.org/10.22592/ode2025n45e338
### copy data into 'dat' and examine data
dat <- dat.rivera2025
dat
## Not run:
suppressPackageStartupMessages(library(meta))
### sensitivity
round(dat$TP / dat$n1, 4)
report1 <- metaprop(TP, n1, data=dat, common=TRUE, random=TRUE, studlab=paste(Author, Year))
report1
summary(report1)
forest(report1)
### specificity
round(dat$TN / dat$n2, 4)
report2 <- metaprop(TN, n2, data=dat, common=TRUE, random=TRUE, studlab=paste(Author, Year))
summary(report2)
forest(report2)
### diagnostic odds ratio
report3 <- metabin(TP, n1, n2-TN, n2, data=dat, sm="OR",common=FALSE, random=TRUE,
studlab=paste(Author, Year), allstudies=TRUE)
summary(report3)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.