| dat.steurer2006 | R Documentation |
Results from 4 trials evaluating single-agent purine analogues in patients with chronic lymphocytic leukaemia.
dat.steurer2006
The data frame contains the following columns:
| author | character | first author |
| year | integer | publication year |
| Ne | integer | number of patients (purine antagonists) |
| Nc | integer | number of patients (alkylator-based) |
| HR | numeric | hazard ratio |
| lowHR | numeric | lower limit |
| uppHR | numeric | upper limit |
| lnHR | numeric | log hazard ratio |
| selnHR | numeric | standard error |
Steurer et al. (2006) conducted a Cochrane review to evaluate the effect of single-agent purine analogues for the treatment of chronic lymphocytic leukaemia. This dataset contains data from the main outcome, overall survival. Note, the hazard ratios and confidence limits have been reported in the Cochrane review with only two significant figures and were recalculated using the reported log hazard ratios and standard errors.
This data set is used as an example in Schwarzer et al. (2015).
medicine, oncology, hazard ratios
Guido Schwarzer, guido.schwarzer@uniklinik-freiburg.de, https://github.com/guido-s/
Steurer, M., Pall, G., Richards, S., Schwarzer, G., Bohlius, J., & Greil, R. (2006). Purine antagonists for chronic lymphocytic leukaemia. Cochrane Database of Systematic Reviews, 3, CD004270. https://doi.org/10.1002/14651858.cd004270.pub2
Schwarzer, G., Carpenter, J. R., & Rücker, G. (2015). Meta-analysis with R. Cham, Switzerland: Springer.
### Show dataset
dat.steurer2006
## Not run:
### Load meta package
suppressPackageStartupMessages(library(meta))
### Use RevMan 5 settings
oldset <- settings.meta("RevMan5")
### Conduct common effect meta-analysis
m1 <- metagen(lnHR, selnHR, data = dat.steurer2006,
studlab = paste(author, year),
sm = "HR", random = FALSE, n.e = Ne, n.c = Nc)
m1
### Same analysis using lower and upper confidence limits
m2 <- metagen(HR, lower = lowHR, upper = uppHR,
data = dat.steurer2006, transf = FALSE,
studlab = paste(author, year),
sm = "HR", random = FALSE, n.e = Ne, n.c = Nc)
m2
### Use previous settings
settings.meta(oldset)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.