Learn R Programming

metadat (version 1.4-0)

dat.stowe2010: Studies on Adjuvant Treatments to Levodopa Therapy for Parkinson disease

Description

Results from 29 trials assessing efficacy of three drug classes as adjuvant treatment to levodopa therapy in patients with Parkinson disease and motor complications.

Usage

dat.stowe2010

Arguments

Format

The data frame contains the following columns:

studycharacterstudy label
idintegerstudy id
t1charactertreatment 1
y1numerictreatment effect arm 1
sd1numericstandard deviation arm 1
n1integersample size arm 1
t2charactertreatment 2
y2numerictreatment effect arm 2
sd2numericstandard deviation arm 2
n2integersample size arm 2
t3charactertreatment 3
y3numerictreatment effect arm 3
sd3numericstandard deviation arm 3
n3integersample size arm 3

Concepts

medicine, raw mean differences, network meta-analysis

Details

This dataset contains data from a Cochrane review assessing efficacy and safety of three drug classes as adjuvant treatment to levodopa therapy in patients with Parkinson disease and motor complications (Stowe et al., 2010).

The authors conducted three pairwise meta-analyses comparing dopamine agonists, catechol-O-methyl transferase inhibitors (COMTI), and monoamine oxidase type B inhibitors (MAOBI) with placebo. The primary outcome was the mean reduction of the time spent in a relatively immobile ‘off’ phase (mean off-time), calculated in hours per day. Relative treatment effects were expressed as mean difference. Data on this outcome were available for 5,331 patients from 28 studies comparing an active treatment with placebo and one three-arm study comparing two active treatments with placebo.

Examples

Run this code
### Show results from three studies (including three-arm study LARGO)
dat.stowe2010[18:20, ]

if (FALSE) {
### Load netmeta package
suppressPackageStartupMessages(library("netmeta"))

### Print mean differences with two digits and standard errors with 3
### digits
oldset <- settings.meta(digits = 2, digits.se = 3)

### Transform data from wide arm-based format to contrast-based
### format. Argument 'sm' must not be provided as the mean difference
### is the default in R function metacont() called internally.
pw <- pairwise(treat = list(t1, t2, t3), n = list(n1, n2, n3),
  mean = list(y1, y2, y3), sd = list(sd1, sd2, sd3),
  studlab = study, data = dat.stowe2010, sm = "MD")

### Show calculated mean differences (TE) for three studies
selstudy <- c("COMTI(E) INT-OZ", "LARGO", "COMTI(E) Nomecomt")
subset(pw, studlab %in% selstudy)[, c(3:7, 10, 1)]

### Conduct random effects network meta-analysis (NMA)
### with placebo as reference
net <- netmeta(pw, fixed = FALSE, ref = "plac")

### Show network graph
netgraph(net, number = TRUE, multiarm = TRUE,
  cex = 1.25, offset = 0.025,
  cex.number = 1, pos.number.of.studies = 0.3)

### Print NMA results
net

### Forest plot with NMA results
forest(net)

### Forest plot showing all network estimates of active treatments
### compared with other treatments
forest(net, ref = c("C", "D", "M"), baseline = FALSE, drop = TRUE)

### Treatment ranking using P-scores
netrank(net)

### Rankogram with all ranking probabilities
set.seed(1909)
ran <- rankogram(net)
ran
plot(ran)

### Treatment ranking using SUCRAs
netrank(ran)

### League table showing network and direct estimates
netleague(net, seq = netrank(net), ci = FALSE)

### Use previous settings
settings.meta(oldset)
}

Run the code above in your browser using DataLab