### Show results from three studies (including three-arm study LARGO)
dat.stowe2010[18:20, ]
if (FALSE) {
### Load netmeta package
suppressPackageStartupMessages(library("netmeta"))
### Print mean differences with two digits and standard errors with 3
### digits
oldset <- settings.meta(digits = 2, digits.se = 3)
### Transform data from wide arm-based format to contrast-based
### format. Argument 'sm' must not be provided as the mean difference
### is the default in R function metacont() called internally.
pw <- pairwise(treat = list(t1, t2, t3), n = list(n1, n2, n3),
mean = list(y1, y2, y3), sd = list(sd1, sd2, sd3),
studlab = study, data = dat.stowe2010, sm = "MD")
### Show calculated mean differences (TE) for three studies
selstudy <- c("COMTI(E) INT-OZ", "LARGO", "COMTI(E) Nomecomt")
subset(pw, studlab %in% selstudy)[, c(3:7, 10, 1)]
### Conduct random effects network meta-analysis (NMA)
### with placebo as reference
net <- netmeta(pw, fixed = FALSE, ref = "plac")
### Show network graph
netgraph(net, number = TRUE, multiarm = TRUE,
cex = 1.25, offset = 0.025,
cex.number = 1, pos.number.of.studies = 0.3)
### Print NMA results
net
### Forest plot with NMA results
forest(net)
### Forest plot showing all network estimates of active treatments
### compared with other treatments
forest(net, ref = c("C", "D", "M"), baseline = FALSE, drop = TRUE)
### Treatment ranking using P-scores
netrank(net)
### Rankogram with all ranking probabilities
set.seed(1909)
ran <- rankogram(net)
ran
plot(ran)
### Treatment ranking using SUCRAs
netrank(ran)
### League table showing network and direct estimates
netleague(net, seq = netrank(net), ci = FALSE)
### Use previous settings
settings.meta(oldset)
}
Run the code above in your browser using DataLab