Learn R Programming

metadat (version 1.4-0)

dat.white2020: Studies on the Relationship between Sexual Signal Expression and Individual Quality

Description

Results from 41 studies examining the relationship between measures of individual quality and the expression of structurally coloured sexual signals.

Usage

dat.white2020

Arguments

Format

The object is a data frame which contains the following columns:

study_idcharacterstudy-level ID
obscharacterobservation-level ID
exp_obscharacterwhether the study is observational or experimental
controlnumericwhether the study did (1) or did not (0) include a non-sexual control trait
classcharacterclass of the study organisms
genuscharacterclass of the study organisms
speciescharacterspecies of the study organisms
sexcharactersex of the study organisms
iridescentnumericwhether the colour signals were iridescent (1) or not (0)
col_varcharacterthe colour variable quantified
col_componentcharacterwhether the colour variable is chromatic or achromatic
quality_measurecharacterthe measure of individual quality used
regioncharacterthe body region from which colour was sampled
nnumericstudy sample size
rnumericPearson's correlation coefficient

Author

Thomas E. White, thomas.white@sydney.edu.au

Concepts

ecology, evolution, correlation coefficients

Details

The 186 rows in this dataset come from 41 experimental and observational studies reporting on the correlation between measures of individual quality (age, body condition, immune function, parasite resistance) and the expression of structurally coloured sexual signals across 28 species. The purpose of this meta-analysis was to test whether structural colour signals show heightened condition-dependent expression, as predicted by evolutionary models of 'honest' signalling.

Examples

Run this code
### copy data into 'dat' and examine data
dat <- dat.white2020
head(dat, 10)

if (FALSE) {
### load metafor package
library(metafor)

### calculate r-to-z transformed correlations and corresponding sampling variances
dat <- escalc(measure="ZCOR", ri=r, ni=n, data=dat)

### fit multilevel meta-analytic model
res <- rma.mv(yi, vi, random = list(~ 1 | study_id, ~ 1 | obs), data=dat)
res
}

Run the code above in your browser using DataLab